#
# spec file for package blocxx
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#



Name:           blocxx
%define blocxx_version 2.1.0
Version:        2.1.0.342
Release:        147.1
License:        BSD3c(or similar)
Group:          Development/Libraries/C and C++
Summary:        BloCXX--C++ Framework for Application Development
Url:            http://sourceforge.net/projects/blocxx/
# current blocxx sources
Source:         %{name}-%{blocxx_version}.tar.bz2
Source2:        baselibs.conf
Patch0:         %{name}-no-fqdn-dot-check.dif
Patch1:         %{name}-no_ipv6_run_check.dif
Patch2:         %{name}-no-condition-test.dif
Patch3:         %{name}-pkgconfig.diff
Patch4:         %{name}-2.1.0-gcc44.dif
Patch5:         %{name}-2.1.0-asneeded.dif
Patch6:         %{name}-2.1.0-memorybarrier.diff
Patch7:         %{name}-2.1.0-catch-gcc45-bug_is_pod.diff
Patch8:         %{name}-2.1.0-std-ptrdiff.diff
Patch9:         blockcxx-openssl.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
#BuildRequires:  gcc-c++ pcre-devel pkg-config
BuildRequires:  gcc-c++ pcre-devel pkgconfig
%if 0%{?suse_version} >= 1030
BuildRequires:  libopenssl-devel
%else
BuildRequires:  openssl-devel
%endif
%if 0%{?fedora_version}
BuildRequires:  pkgconfig
%endif
%define         blocxx_docdir %{_defaultdocdir}/blocxx

%description
BloCXX is a general C++ framework for application development. This
package contains the BloCXX library.

%package -n libblocxx-devel
License:        BSD3c(or similar)
Summary:        BloCXX--C++ Framework for Application Development
Group:          Development/Libraries/C and C++
Requires:       libblocxx6 = %{version}
Requires:       libstdc++-devel pcre-devel
%if 0%{?suse_version} >= 1030
Requires:       libopenssl-devel
%else
Requires:       openssl-devel
%endif
Obsoletes:      %{name}-devel < %{version}
Provides:       %{name}-devel = %{version}
# bug437293
%ifarch ppc64
Obsoletes:      blocxx-devel-64bit
%endif
#

%description -n libblocxx-devel
BloCXX is a general C++ framework for application development. This
package contains the BloCXX library.

%package -n libblocxx6
License:        BSD3c(or similar)
Summary:        BloCXX--C++ Framework for Application Development
Group:          Development/Libraries/C and C++
# bug437293
%ifarch ppc64
Obsoletes:      blocxx-64bit
%endif
#
#satisfy debuginfo package
Provides:       blocxx = %{version}-%{release}
Obsoletes:      blocxx < %{version}

%description -n libblocxx6
BloCXX is a general C++ framework for application development. This
package contains the BloCXX library.

%prep
%setup -q -n blocxx-%{blocxx_version}
%patch0 -p0
%patch1 -p0
%patch2 -p0
%patch3 -p0
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p0
%patch8 -p0
%patch9

%build

if test -f ./bootstrap.sh ; then
    ./bootstrap.sh
else
    %{?suse_update_config:%{suse_update_config -f}}
    :
fi
autoreconf -fi

%if %{?_with_debug:1}%{!?_with_debug:0}
#
# configure a special debug version
#
CFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing" \
CXXFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing" \
%configure \
	%ifarch hppa
	--target=hppa2.0-suse-linux-gnu \
	%endif
	--enable-ipv6 \
	%ifarch %ix86
	--enable-valgrind-support \
	%endif
	--enable-stack-trace \
	--enable-debug-mode \
	--disable-Werror
%else
#
# configure normal version
#
CFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing" \
CXXFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing" \
%configure \
	%ifarch hppa
	--target=hppa2.0-suse-linux-gnu \
	%endif
	--enable-ipv6 \
	--enable-iconv \
	--disable-Werror
%endif
#
# compile
#
make %{?_smp_mflags}

%check
#
# run testsuites
%if !0%{?qemu_user_space_build:1}
make check %{?_smp_mflags}
%endif
#

%install
#
# install the library completely
#
make DESTDIR=${RPM_BUILD_ROOT} install
#
# add version to the library file name
#
mv -f ${RPM_BUILD_ROOT}%_libdir/libblocxx.so.6 \
      ${RPM_BUILD_ROOT}%_libdir/libblocxx.so.6.%{blocxx_version}
ln -s libblocxx.so.6.%{blocxx_version} \
      ${RPM_BUILD_ROOT}%_libdir/libblocxx.so.6
#
# install documentation files
#
install -m755 -d ${RPM_BUILD_ROOT}/%{blocxx_docdir}
for f in LICENSE AUTHORS ChangeLog ; do
  install -m644 $f ${RPM_BUILD_ROOT}/%{blocxx_docdir}/
done
# --disable-static not implemented here
rm -fv %{buildroot}%{_libdir}/*.a

%post -n libblocxx6 -p /sbin/ldconfig

%postun -n libblocxx6 -p /sbin/ldconfig

%files -n libblocxx-devel
%defattr(-,root,root)
%_includedir/blocxx
%_libdir/libblocxx.so
%_libdir/pkgconfig/blocxx.pc
%_datadir/aclocal/blocxx.m4
%dir %blocxx_docdir
%doc %blocxx_docdir/LICENSE
%doc %blocxx_docdir/AUTHORS
%doc %blocxx_docdir/ChangeLog

%files -n libblocxx6
%defattr(-,root,root)
%_libdir/libblocxx.so.6
%_libdir/libblocxx.so.6.%{blocxx_version}

%changelog
* Fri Sep 30 2011 crrodriguez@opensuse.org
- Workaround qemu-arm current limitations/bugs
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
- Enable baselibs for arches
* Sun Aug 14 2011 crrodriguez@opensuse.org
- Add patch to make the library use AES-NI or other openssl engines
* Fri Feb 25 2011 mt@suse.de
- Fixed to use std::ptrdiff_t in Enumeration.hpp (gcc 4.6).
- Fixed libblocxx-devel (self) obsolete flags in spec file.
* Sat Apr 24 2010 coolo@novell.com
- buildrequire pkg-config to fix provides
* Tue Mar 30 2010 mt@suse.de
- Dropped obsolete libblocxx4 compatibility sub-package.
* Fri Mar 12 2010 mt@suse.de
- Test for char ptr pod struct to mark is_pod non-functional
  and avoid build failures -- reported as gcc 4.5 bug 43333.
- Added -fno-strict-aliasing to compile flags
* Sun Jan 31 2010 jengelh@medozas.de
- Package baselibs.conf
* Tue Sep 15 2009 mt@suse.de
- Changed to use GCC 4.1+ __sync_synchronize as in svn instead
  of manual inline asm MemoryBarriers (blocxx issue #2799341),
  removed obsolete ARM_asm.diff patch.
* Fri Jul 17 2009 jansimon.moeller@opensuse.org
- add __asm__ for ARM
* Thu Jul  9 2009 mt@suse.de
- improved asneeded patch to use -pthread in shared lib flags too
* Sat Jun 20 2009 coolo@novell.com
- fix link to pthread
* Mon Mar  2 2009 crrodriguez@suse.de
- remove static libraries (and save 13.9MB space)
* Tue Feb 17 2009 mt@suse.de
- fixed to include cstdio instead of stdio.h in gcc 4.4 fix
* Tue Feb 17 2009 coolo@suse.de
- fix compilation with gcc 4.4
* Thu Jan 29 2009 olh@suse.de
- obsolete libblocxx-XXbit in the library subpackage
* Wed Dec 10 2008 olh@suse.de
- use Obsoletes: -XXbit only for ppc64 to help solver during distupgrade
  (bnc#437293)
* Tue Nov 11 2008 ro@suse.de
- SLE-11 uses PPC64 instead of PPC, adapt baselibs.conf
* Thu Oct 30 2008 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Tue Jun  3 2008 coolo@suse.de
- obsolete blocxx for rename
* Wed May 28 2008 ro@suse.de
- fix baselibs.conf file
* Sat May 17 2008 schwab@suse.de
- Fix pkgconfig file.
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Thu Nov 22 2007 bg@suse.de
- use --target=hppa2.0-suse-linux-gnu to make this build on hppa.
  We don't have older machines, and they would be too slow anyways.
* Wed Nov 21 2007 ro@suse.de
- provide main package name in libblocxx6 for debuginfo
* Fri Nov  9 2007 mt@suse.de
- Updated to blocxx-2.1.0, svn-trunk revision 342 / merged from
  the blocxx:head project in opensuse build service.
- Changed to use libblocxx6 package to provide the shared library
  and libblocxx-devel for the development files according to the
  opensuse library packaging policy.
- Moved blocxx-1.0 compatibility build into libblocxx4.spec file.
- Disabled Condition testsuite (solaris test fails on x86_64).
- Corrected broken entries in the blocxx.changes file
* Tue Apr 11 2006 cthiel@suse.de
- Reduce BuildRequires
* Mon Mar 27 2006 mt@suse.de
- Fix/Workaround in RWLocker testcase: hold the lock longer
  and get another thread a chance to run into the exception
- Fix/Workaround in IPCMutex testcase: sync the client start
  and let the other process more time to set its own lock
- New patch file: blocxx-testsuite01.dif
* Fri Mar 17 2006 mt@suse.de
- Readded run_ldconfig macro run in post, unintentionally
  removed while blocxx-doc split
* Mon Mar 13 2006 mt@suse.de
- Moved blocxx-doc subpackage into a separate noarch package
* Fri Feb 10 2006 mt@suse.de
- Fix for String::indexOf() - a int variable was used instead of
  size_t, that may cause a potential overflow.
- Resource leak in Mutex implementations: the pthread_mutexattr_t
  variable was not destroyed after it is not needed any more.
- Fix for COWReferenceBase/COWReference -- if somebody used the
  COWReference::cast_to() function, compilation fails because
  of missed implementation of useRefCountOf function.
- Fix for COWReference::cast_to() to not to increment ref counter.
- Added String::String(const std::string &str) constructor.
- Removed blocxx::off_t from blocxx/Types.hpp
- Minor portability fixes to build on Mac OS X.
- Makefile.am fixes causing failures on "make distcheck"
- Documentation and ChangeLog cleanups
- Enabled testsuite run (make check) in spec file, cleaned up
- Bug #149127, increased version number to 1.0.0
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan  4 2006 mc@suse.de
- Updated to cvs snapshot 20060104 adding fixes synced from OpenWBEM
* Wed Oct 19 2005 mt@suse.de
- Updated to cvs snapshot 20051019 fixing the BLOCXX_THROW_ERRNO
  and BLOCXX_THROW_ERRNO_MSG macros to be useable outside of the
  blocxx namespace as well.
* Mon Oct 10 2005 mt@suse.de
- Updated to cvs snapshot 20051010 adding fixes synced from OpenWBEM,
  like avoiding to escape of an exec exception from initRandomnes()
  in CryptographicRandomNumber, fixes/improvements to event handling
  in Select functions, missed initialization in DateTime::set().
* Fri Aug 12 2005 mt@suse.de
- Updated to cvs snapshot 20050812 fixing handling of quoted
  capture references in Perl/PosixRegEx replace() methods
* Wed Aug 10 2005 mt@suse.de
- Updated to cvs snapshot 20050810 adding identity and facility
  arguments to the SyslogAppender.
* Mon Jul 25 2005 mt@suse.de
- Updated to cvs snapshot 20050725 improving large file support.
* Thu Jul 21 2005 mt@suse.de
- Updated to cvs snapshot 20050721 enabling large file support.
* Thu Jul 14 2005 mt@suse.de
- Updated to cvs snapshot 0.9.20050714 providing minor
  cleanups only
* Mon Jul 11 2005 mt@suse.de
- Updated to cvs snapshot 0.9.20050711 providing blocxx.pc
  pkg-config file, removeing -R flag from blocxx.m4 file
  and fixing a bug in EnvVars::getenvp()
- Added libstdc++-devel pcre-devel requirements to spec file
* Fri Jul  8 2005 mt@suse.de
- Updated to cvs snapshot 0.9.20050708 adding shared locks
  to File class, fixing Exec/EnvVars to allow to execute
  with empty environmens and other minor improvements
* Tue Jun 21 2005 mt@suse.de
- Updated to cvs snapshot 0.9.20050621;
  provides new pcre based PerlRegEx class and
  improved RegEx class renamed to PosixRegEx
* Thu Jun 16 2005 mt@suse.de
- Updated to cvs snapshot 0.9.20050616;
  improvements in RegEx class, regex examples
* Tue Jun 14 2005 mt@suse.de
- Updated to cvs snapshot 0.9.20050614;
  small enable_ssl dependency fix in configure.in
* Mon Jun 13 2005 mt@suse.de
- Disabled SSL support, since it conflicts with SSL code in
  openwbem, e.g. if blocxx is used to implement a provider.
* Thu Jun  9 2005 mt@suse.de
- Updated to cvs snapshot 0.9.20050609;
  contains errno fix in Select.cpp
* Fri May 20 2005 mt@suse.de
- Updated to cvs snapshot from 20050520
* Tue May 10 2005 uli@suse.de
- don't use dot on ARM (hangs on some source files)
* Tue Apr 26 2005 mt@suse.de
- Updated to cvs snapshot from 20050426 including fix
  for blocxx.m4 (lib64) and obsoleting configure.in dif.
- Fixed last changelog entry (date)
* Tue Apr 26 2005 mt@suse.de
- Updated to cvs snapshot from 20050425
* Fri Apr 15 2005 mt@suse.de
- Updated to cvs snapshot from 20050425
* Fri Apr 15 2005 mt@suse.de
- Updated to cvs snapshot from 20050415 providing additional
  Logger interfaces and diverse error checking improvements.
- Changed to use --without-docs rpmbuild option in spec file
  to allow to skip the generation of documentation and use a
  pre-build archive instead. Default is to build documentation
  since it contains architecture/feature depending references.
* Sat Apr  9 2005 bwhiteley@suse.de
- fixed 64bit pointer issue in IPCMutexTestCases
* Thu Apr  7 2005 mt@suse.de
- initial package checkin, cvs snapshot 20050407
